## populating variables ##
## change the $apikey, $temppath, $sourcepath, $destinationpath, $resultantshowname and $seriesid variables to suit your needs/environment ##

$apikey = "x"
$sourcepath = "x"
$temppath = "x"
$destinationpath = "x"
$log = "x"
$seriesid = "x"
$resultantshowname = "x"  ## you'll want this to be something like "colbert.report" or "tonight.show" ## 


mkdir $temppath
$date =  get-date 
Add-Content $log `n
Add-Content $log $date

## old method of pulling down the uncompresed xml file - prettier code but not nice for bandwidth (you're welcome, thetvdb) ##
## $webClient = new-object System.Net.WebClient
## $epinfo = [xml]$webClient.DownloadString(http://thetvdb.com/api/$apikey/series/$seriesid/all/en.xml)


## downloading the xml file for the series inside a more bandwidth-friendly zip file ##

$webClient = new-object System.Net.WebClient
$webpath = "http://thetvdb.com/api/$apikey/series/$seriesid/all/en.zip"
$zippath = "$temppath\en.zip"
$webClient.Downloadfile($webpath, $zippath)

## unpacking file into a temp folder ##

$zip = new-object -com shell.application
$shelldest = $zip.NameSpace("$temppath")
$shellzip = $zip.NameSpace($zippath)
$shelldest.CopyHere($shellzip.Items())

## importing the xml into an array variable ##

$epinfo = [xml](gc "$temppath\en.xml")

## building an array of the all mis-named files (excluding folders) ##

$files = gci $sourcepath -r | ?{!$_.PSIsContainer} | sort -prop creationtime 

## iterate through the array we just created to find out what it's airdate is, based on filename (potential for problems if file name doesnt follow YYYY.MM.DD syntax) ##

foreach($file in $files){

# Replace the periods in the file name with dashes so it will match up with the date format used by TVDB
$fname = $file.name.replace(".", "-")
$myshow = $epinfo.data | foreach{$_.episode} |?{$fname.Contains($_.firstaired) -AND $_.firstaired -ne ""} | select EpisodeNumber,SeasonNumber,EpisodeName,FirstAired

if($myshow){
# Format episode numbers so they are at least 2 digits.  The number of zeros in the To.String line specifies the minum number of digits.
[int]$epnum = $myshow.EpisodeNumber
$paddedepnum = $epnum.ToString("00")

#Extract extension from file name
$l = $file.name.length
$l = $l-4
$fileext = $file.name.substring($l,4)

$airdate = $myshow.FirstAired.replace("-",".")

#This will be the file name of the copied file
$showname = $resultantshowname+".S"+$myshow.SeasonNumber+"E"+$paddedepnum+"."+$myshow.EpisodeName+"."+$airdate+$fileext

$showcon = 'Copied "'+$showname+'"'
Add-Content $log $showcon

cp $file.pspath $destinationpath\$showname
}

else{
$filefail = 'Failed to match "'+$file.name+'"'
Add-Content $log $filefail
}

## Uncomment the two lines below to delete the original copies after copying.
# rm $file.pspath
# rm $file.directory
}

## cleanup the temp directory##

rm $temppath -recurse
